import gbdtransformation.brands.ipas.filters as ipas

ignore_namespace = [
   'http://www.wipo.int/standards/XMLSchema/trademarks',
   'http://www.wipo.int/standards/XMLSchema/wo-trademarks']

def get_appdate(appdate, appnum):
    return ipas.get_appdate(appdate, appnum)

def translate_type(header):
    code = header.TransactionCode

    if code == 'Trademark': return 'TRADEMARK'
    if code == 'Trademark-Madrid': return 'TRADEMARK'

    raise Exception('Type "%s" is not mapped.' % code)

def translate_kind(trademark, header):
    kind = trademark.KindMark

    if kind == 'Individual': return ['Individual']
    if kind == 'Certificate': return ['Certificate']
    if kind == 'Collective': return ['Collective']

    raise Exception('Kind "%s" not mapped.' % kind)

def translate_status(trademark):
    status = trademark.MarkCurrentStatusCode

    if status == 'M40': return 'Unknown'
    if status == 'M009': return 'Unknown'
    if status == 'CPN': return 'Unknown'
    if status == 'RNN': return 'Unknown'

    return ipas.translate_status(status)

def translate_feature(trademark):
    feature = trademark.MarkFeature

    if not feature: return 'Undefined'

    return ipas.translate_feature(feature)

def translate_event(event):
    return ipas.translate_event(event)

# ---------------------------------------

def verbal_lang_map(markVerbalElements, applang=None):
    return ipas.verbal_lang_map(markVerbalElements, applang=applang)

def get_registration_nb(trademark, tmstatus):
    if trademark.RegistrationNumber:
        return trademark.RegistrationNumber

    if not tmstatus in ['Expired', 'Registered']:
        return None

    # 2227 => 2227
    return trademark.ApplicationNumber

def get_expiry_date(trademark, tmstatus):
    return ipas.get_expiry_date(trademark, tmstatus)

def get_registration_date(trademark, tmstatus):
    return ipas.get_registration_date(trademark, tmstatus)

def is_international(content):
    return content.TransactionCode == 'Trademark-Madrid'

def get_ir_refnum(appnum):
    return appnum

def get_goods_services(goods_services):
    return ipas.get_goods_services(goods_services)
